############
Installation
############

Requirements
============

``csdmpy`` has the following strict requirements:

- `Python <https://www.python.org>`_ 3.6 or later
- `Numpy <https://numpy.org>`_ 1.17 or later

Other requirements include:

- `requests>=2.21.0 <http://docs.python-requests.org/en/master/>`_
  (for downloading files from server)
- `astropy>=3.0 <http://www.astropy.org>`_ (for astropy units module)
- `matplotlib>=3.0 <https://matplotlib.org>`_ (for rendering plots)


Installing ``csdmpy``
=====================

**Using PIP**:

PIP is a package manager for Python packages and is included with python version 3.4
and higher. PIP is the easiest way to install python packages.

.. code-block:: bash

    $ pip install csdmpy -U
